@@ -32,6 +32,7 @@
 
 #include "map.h"
 #include "mapobject.h"
+#include "tile.h"
 
 using namespace Tiled;
 
@@ -68,6 +69,17 @@ int ObjectGroup::removeObject(MapObject *object)
     return index;
 }
 
+bool ObjectGroup::referencesTileset(const Tileset *tileset) const
+{
+    foreach (const MapObject *object, mObjects) {
+        const Tile *tile = object->tile();
+        if (tile && tile->tileset() == tileset)
+            return true;
+    }
+
+    return false;
+}
+
 void ObjectGroup::resize(const QSize &size, const QPoint &offset)
 {
     Layer::resize(size, offset);
@@ -129,5 +141,6 @@ ObjectGroup *ObjectGroup::initializeClone(ObjectGroup *clone) const
     Layer::initializeClone(clone);
     foreach (MapObject *object, mObjects)
         clone->addObject(object->clone());
+    clone->setColor(mColor);
     return clone;
 }
