@@ -296,6 +296,7 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     toolManager->registerTool(mBucketFillTool);
     toolManager->registerTool(new Eraser(this));
     toolManager->registerTool(new SelectionTool(this));
+    toolManager->addSeparator();
     toolManager->registerTool(new ObjectSelectionTool(this));
     toolManager->registerTool(areaObjectsTool);
     toolManager->registerTool(tileObjectsTool);
@@ -318,6 +319,14 @@ MainWindow::MainWindow(QWidget *parent, Qt::WFlags flags)
     connect(mDocumentManager, SIGNAL(documentCloseRequested(int)),
             this, SLOT(closeMapDocument(int)));
 
+    QShortcut *switchToLeftDocument = new QShortcut(tr("Ctrl+PgUp"), this);
+    connect(switchToLeftDocument, SIGNAL(activated()),
+            mDocumentManager, SLOT(switchToLeftDocument()));
+
+    QShortcut *switchToRightDocument = new QShortcut(tr("Ctrl+PgDown"), this);
+    connect(switchToRightDocument, SIGNAL(activated()),
+            mDocumentManager, SLOT(switchToRightDocument()));
+
     updateActions();
     readSettings();
     setupQuickStamps();
@@ -530,10 +539,10 @@ void MainWindow::openFile()
         filter += reader->nameFilter();
     }
 
-    QString fileName = QFileDialog::getOpenFileName(this, tr("Open Map"),
+    QStringList fileNames = QFileDialog::getOpenFileNames(this, tr("Open Map"),
                                                     fileDialogStartLocation(),
                                                     filter, &selectedFilter);
-    if (fileName.isEmpty())
+    if (fileNames.isEmpty())
         return;
 
     // When a particular filter was selected, use the associated reader
@@ -544,7 +553,8 @@ void MainWindow::openFile()
     }
 
     mSettings.setValue(QLatin1String("lastUsedOpenFilter"), selectedFilter);
-    openFile(fileName, mapReader);
+    foreach (const QString &fileName, fileNames)
+        openFile(fileName, mapReader);
 }
 
 bool MainWindow::saveFile(const QString &fileName)
@@ -1129,11 +1139,6 @@ void MainWindow::addMapDocument(MapDocument *mapDocument)
 {
     mDocumentManager->addDocument(mapDocument);
 
-    connect(mapDocument, SIGNAL(currentLayerChanged(int)),
-            SLOT(updateActions()));
-    connect(mapDocument, SIGNAL(tileSelectionChanged(QRegion,QRegion)),
-            SLOT(updateActions()));
-
     MapView *mapView = mDocumentManager->currentMapView();
     connect(mapView->zoomable(), SIGNAL(scaleChanged(qreal)),
             this, SLOT(updateZoomLabel()));
@@ -1162,6 +1167,9 @@ void MainWindow::retranslateUi()
 
 void MainWindow::mapDocumentChanged(MapDocument *mapDocument)
 {
+    if (mMapDocument)
+        mMapDocument->disconnect(this);
+
     mMapDocument = mapDocument;
 
     mActionHandler->setMapDocument(mMapDocument);
@@ -1169,6 +1177,15 @@ void MainWindow::mapDocumentChanged(MapDocument *mapDocument)
     mTilesetDock->setMapDocument(mMapDocument);
     AutomaticMappingManager::instance()->setMapDocument(mMapDocument);
 
+    if (mMapDocument) {
+        connect(mMapDocument, SIGNAL(fileNameChanged()),
+                SLOT(updateWindowTitle()));
+        connect(mMapDocument, SIGNAL(currentLayerChanged(int)),
+                SLOT(updateActions()));
+        connect(mMapDocument, SIGNAL(tileSelectionChanged(QRegion,QRegion)),
+                SLOT(updateActions()));
+    }
+
     updateWindowTitle();
     updateActions();
 }
