@@ -26,8 +26,7 @@
 
 #include <QGraphicsScene>
 #include <QMap>
-
-class QModelIndex;
+#include <QSet>
 
 namespace Tiled {
 
@@ -40,6 +39,7 @@ namespace Internal {
 class AbstractTool;
 class MapDocument;
 class MapObjectItem;
+class MapScene;
 class ObjectGroupItem;
 
 /**
@@ -75,6 +75,42 @@ public:
      */
     bool isGridVisible() const { return mGridVisible; }
 
+    /**
+     * Returns the selected object group item, or 0 if no object group is
+     * selected.
+     */
+    ObjectGroupItem *selectedObjectGroupItem() const
+    { return mSelectedObjectGroupItem; }
+
+    /**
+     * Returns the set of selected map object items.
+     */
+    const QSet<MapObjectItem*> &selectedObjectItems() const
+    { return mSelectedObjectItems; }
+
+    /**
+     * Sets the set of selected map object items.
+     */
+    void setSelectedObjectItems(const QSet<MapObjectItem*> &items);
+
+    /**
+     * Sets the set of selected map object items to those matching the given
+     * \a objects.
+     */
+    void setSelectedObjects(const QList<MapObject*> &objects);
+
+    /**
+     * Enables the selected tool at this map scene.
+     * Therefore it tells that tool, that this is the active map scene.
+     */
+    void enableSelectedTool();
+    void disableSelectedTool();
+
+    /**
+     * Sets the currently selected tool.
+     */
+    void setSelectedTool(AbstractTool *tool);
+
 public slots:
     /**
      * Sets whether the tile grid is visible.
@@ -99,11 +135,6 @@ protected:
     void dragEnterEvent(QGraphicsSceneDragDropEvent *event);
 
 private slots:
-    /**
-     * Sets the currently selected tool.
-     */
-    void setSelectedTool(AbstractTool *tool);
-
     /**
      * Refreshes the map scene.
      */
@@ -132,19 +163,10 @@ private:
 
     void updateInteractionMode();
 
-    void enableSelectedTool();
-    void disableSelectedTool();
-
-    void startNewMapObject(const QPointF &pos);
-    MapObject *clearNewMapObjectItem();
-    void cancelNewMapObject();
-    void finishNewMapObject();
-
     bool eventFilter(QObject *object, QEvent *event);
 
     MapDocument *mMapDocument;
     ObjectGroupItem *mSelectedObjectGroupItem;
-    MapObjectItem *mNewMapObjectItem;
     AbstractTool *mSelectedTool;
     AbstractTool *mActiveTool;
     bool mGridVisible;
@@ -155,6 +177,7 @@ private:
 
     typedef QMap<MapObject*, MapObjectItem*> ObjectItems;
     ObjectItems mObjectItems;
+    QSet<MapObjectItem*> mSelectedObjectItems;
 };
 
 } // namespace Internal
