@@ -21,11 +21,14 @@
 
 #include "tilesetdock.h"
 
+#include "addremovemapobject.h"
 #include "addremovetileset.h"
 #include "erasetiles.h"
 #include "map.h"
 #include "mapdocument.h"
+#include "mapobject.h"
 #include "movetileset.h"
+#include "objectgroup.h"
 #include "tile.h"
 #include "tilelayer.h"
 #include "tileset.h"
@@ -61,6 +64,7 @@ TilesetDock::TilesetDock(QWidget *parent):
 
     mTabBar->setTabsClosable(true);
     mTabBar->setMovable(true);
+    mTabBar->setUsesScrollButtons(true);
 
     connect(mTabBar, SIGNAL(currentChanged(int)),
             mViewStack, SLOT(setCurrentIndex(int)));
@@ -96,6 +100,10 @@ void TilesetDock::setMapDocument(MapDocument *mapDocument)
     while (mViewStack->currentWidget())
         delete mViewStack->currentWidget();
 
+    // Clear all connections to the previous document
+    if (mMapDocument)
+        mMapDocument->disconnect(this);
+
     mMapDocument = mapDocument;
 
     if (mMapDocument) {
@@ -239,10 +247,10 @@ void TilesetDock::tilesetMoved(int from, int to)
 void TilesetDock::removeTileset(int index)
 {
     Tileset *tileset = tilesetViewAt(index)->tilesetModel()->tileset();
-    bool inUse = false;
+    const bool inUse = mMapDocument->map()->isTilesetUsed(tileset);
 
     // If the tileset is in use, warn the user and confirm removal
-    if (mMapDocument->map()->isTilesetUsed(tileset)) {
+    if (inUse) {
         QMessageBox warning(QMessageBox::Warning,
                             tr("Remove Tileset"),
                             tr("The tileset \"%1\" is still in use by the "
@@ -255,8 +263,6 @@ void TilesetDock::removeTileset(int index)
 
         if (warning.exec() != QMessageBox::Yes)
             return;
-
-        inUse = true;
     }
 
     QUndoCommand *remove = new RemoveTileset(mMapDocument, index, tileset);
@@ -266,12 +272,20 @@ void TilesetDock::removeTileset(int index)
         // Remove references to tiles in this tileset from the current map
         undoStack->beginMacro(remove->text());
         foreach (Layer *layer, mMapDocument->map()->layers()) {
-            if (TileLayer *tileLayer = dynamic_cast<TileLayer*>(layer)) {
+            if (TileLayer *tileLayer = layer->asTileLayer()) {
                 const QRegion refs = tileLayer->tilesetReferences(tileset);
                 if (!refs.isEmpty()) {
                     undoStack->push(new EraseTiles(mMapDocument,
                                                    tileLayer, refs));
                 }
+            } else if (ObjectGroup *objectGroup = layer->asObjectGroup()) {
+                foreach (MapObject *object, objectGroup->objects()) {
+                    const Tile *tile = object->tile();
+                    if (tile && tile->tileset() == tileset) {
+                        undoStack->push(new RemoveMapObject(mMapDocument,
+                                                            object));
+                    }
+                }
             }
         }
     }
