@@ -26,6 +26,19 @@
 &lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;</translation>
     </message>
 </context>
+<context>
+    <name>CommandDialog</name>
+    <message>
+        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
+        <source>Properties</source>
+        <translation>Vlastnosti</translation>
+    </message>
+    <message>
+        <location line="+21"/>
+        <source>Save map before executing</source>
+        <translation>Uložit mapu před spuštěním</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -34,7 +47,7 @@
         <translation>Tiled</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="+23"/>
         <source>&amp;File</source>
         <translation>&amp;Soubor</translation>
     </message>
@@ -44,7 +57,7 @@
         <translation>&amp;Nedávno otevřené soubory</translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="+23"/>
         <source>&amp;Edit</source>
         <translation>&amp;Editace</translation>
     </message>
@@ -59,12 +72,12 @@
         <translation>&amp;Mapa</translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+13"/>
         <source>&amp;View</source>
         <translation>&amp;Zobrazení</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+17"/>
         <source>Main Toolbar</source>
         <translation>Hlavní pruh nástrojů</translation>
     </message>
@@ -113,6 +126,11 @@
         <source>Map &amp;Properties...</source>
         <translation>&amp;Vlastnosti mapy...</translation>
     </message>
+    <message>
+        <location line="+5"/>
+        <source>AutoMap</source>
+        <translation>Automatická mapa</translation>
+    </message>
     <message>
         <location line="+8"/>
         <source>Show &amp;Grid</source>
@@ -149,7 +167,22 @@
         <translation>Přidat externí &amp;vrstvu dlaždic...</translation>
     </message>
     <message>
-        <location line="-97"/>
+        <location line="+8"/>
+        <source>&amp;Snap to Grid</source>
+        <translation>&amp;Přichytávat na mřížku</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>C&amp;lose All</source>
+        <translation>Zavřít &amp;vše</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Ctrl+Shift+W</source>
+        <translation>Ctrl+Shift+W</translation>
+    </message>
+    <message>
+        <location line="-113"/>
         <source>New &amp;Tileset...</source>
         <translation>Nová sada &amp;dlaždic...</translation>
     </message>
@@ -212,19 +245,123 @@
 <context>
     <name>MapObjectItem</name>
     <message>
-        <location filename="../src/tiled/mapobjectitem.cpp" line="+265"/>
         <source>&amp;Duplicate Object</source>
-        <translation>&amp;Duplikovat objekt</translation>
+        <translation type="obsolete">&amp;Duplikovat objekt</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>&amp;Remove Object</source>
-        <translation>&amp;Odstranění objektu</translation>
+        <translation type="obsolete">&amp;Odstranění objektu</translation>
+    </message>
+    <message>
+        <source>Object &amp;Properties...</source>
+        <translation type="obsolete">&amp;Vlastnosti objektu...</translation>
+    </message>
+</context>
+<context>
+    <name>MapReader</name>
+    <message>
+        <location filename="../src/libtiled/mapreader.cpp" line="+132"/>
+        <source>Not a map file.</source>
+        <translation>Toto není soubor s mapou.</translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <source>Not a tileset file.</source>
+        <translation>Toto není soubor se sadou dlaždic.</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <source>%3
+
+Line %1, column %2</source>
+        <translation>%3
+
+Řádek: %1, sloupec: %2</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>File not found: %1</source>
+        <translation>Soubor nenalezen: %1</translation>
     </message>
     <message>
         <location line="+3"/>
-        <source>Object &amp;Properties...</source>
-        <translation>&amp;Vlastnosti objektu...</translation>
+        <source>Unable to read file: %1</source>
+        <translation>Nepodařilo se přečíst soubor: %1</translation>
+    </message>
+    <message>
+        <location line="+61"/>
+        <source>Unsupported map orientation: &quot;%1&quot;</source>
+        <translation>Nepodporovaná orientace mapy: &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <location line="+56"/>
+        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
+        <translation>Špatné parametry sady dlaždic &apos;%1&apos;</translation>
+    </message>
+    <message>
+        <location line="+21"/>
+        <source>Error while loading tileset &apos;%1&apos;: %2</source>
+        <translation>Chyba při načítání sady dlaždic &apos;%1&apos;: %2</translation>
+    </message>
+    <message>
+        <location line="+21"/>
+        <source>Invalid tile ID: %1</source>
+        <translation>Neplatné ID dlaždice: %1</translation>
+    </message>
+    <message>
+        <location line="+34"/>
+        <source>Error loading tileset image:
+&apos;%1&apos;</source>
+        <translation>Chyba načítání obrázku sady dlaždic: &apos;%1&apos;</translation>
+    </message>
+    <message>
+        <location line="+64"/>
+        <source>Too many &lt;tile&gt; elements</source>
+        <translation>Příliš mnoho elementů &lt;title&gt;</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <location line="+66"/>
+        <location line="+39"/>
+        <location line="+103"/>
+        <source>Invalid tile: %1</source>
+        <translation>Neplatné jméno: %1</translation>
+    </message>
+    <message>
+        <location line="-188"/>
+        <source>Unknown encoding: %1</source>
+        <translation>Neplatné kódování: %1</translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <source>Compression method &apos;%1&apos; not supported</source>
+        <translation>Kompresní metoda &apos;%1&apos; není podporována</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <location line="+39"/>
+        <source>Corrupt layer data for layer &apos;%1&apos;</source>
+        <translation>Špatná data vrstvy &apos;%1&apos;</translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
+        <translation>Nepodařilo se přečíst jméno na (%1, %2) ve vrstvě &apos;%3&apos;</translation>
+    </message>
+    <message>
+        <location line="+20"/>
+        <source>Invalid global tile id (less than 0): %1</source>
+        <translation>Neplatné globální ID dlaždice (menší než 0): %1</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Tile used but no tilesets specified</source>
+        <translation>Použití dlaždice bez sady dlaždic</translation>
+    </message>
+    <message>
+        <location filename="../src/libtiled/mapwriter.cpp" line="+102"/>
+        <source>Could not open file for writing.</source>
+        <translation>Nepodařilo se otevřít soubor pro zápis.</translation>
     </message>
 </context>
 <context>
@@ -514,6 +651,11 @@
         <source>&amp;Language:</source>
         <translation>&amp;Jazyk:</translation>
     </message>
+    <message>
+        <location line="+13"/>
+        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
+        <translation>Hardwarově &amp;akcelerované vykreslování (OpenGL)</translation>
+    </message>
 </context>
 <context>
     <name>PropertiesDialog</name>
@@ -526,7 +668,7 @@
 <context>
     <name>ResizeDialog</name>
     <message>
-        <location filename="../src/tiled/resizedialog.ui" line="+13"/>
+        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
         <source>Resize</source>
         <translation>Změnit velikost</translation>
     </message>
@@ -604,32 +746,230 @@
         <translation>&amp;Zobrazovat mířížku</translation>
     </message>
 </context>
+<context>
+    <name>Tengine::TenginePlugin</name>
+    <message>
+        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
+        <source>Could not open file for writing.</source>
+        <translation>Nepodařilo se otevřít soubor pro zápis.</translation>
+    </message>
+    <message>
+        <location line="+243"/>
+        <source>T-Engine4 map files (*.lua)</source>
+        <translation>Mapové soubory T-Engine4 (*.lua)</translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::AutoMapper</name>
+    <message>
+        <location filename="../src/tiled/automap.cpp" line="+116"/>
+        <source>Multiple layers %1 found!</source>
+        <translation>Nalezeno více vrstev %1!</translation>
+    </message>
+    <message>
+        <location line="+115"/>
+        <source>No ruleRegions layer found!</source>
+        <translation>Nenalezena vrstva „ruleRegions“!</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>No set layers found!</source>
+        <translation>Nenalezeny vrstvy „set“!</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>No ruleSet layer found!</source>
+        <translation>Nenalezena vrstva „ruleSet“!</translation>
+    </message>
+    <message>
+        <location line="+208"/>
+        <source>Tile</source>
+        <translation>Dlaždice</translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::AutomaticMappingManager</name>
+    <message>
+        <location line="+491"/>
+        <source>No set layer found!</source>
+        <translation>Nenalezena vrstva „set“!</translation>
+    </message>
+    <message>
+        <location line="+29"/>
+        <source>Apply AutoMap rules</source>
+        <translation>Použít pravidla automatické mapy</translation>
+    </message>
+    <message>
+        <location line="+18"/>
+        <source>No rules file found at:
+%1</source>
+        <translation>Soubor s pravidly nenalezen: %1</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Error opening rules file:
+%1</source>
+        <translation>Chyba při otevírání souboru s pravidly: %1</translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <source>File not found:
+%1</source>
+        <translation>Soubor nenalezen: %1</translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>Opening rules map failed:
+%1</source>
+        <translation>Nepodařilo se otevřít mapu s pravidly: %1</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::BucketFillTool</name>
     <message>
         <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
-        <location line="+139"/>
+        <location line="+133"/>
         <source>Bucket Fill Tool</source>
         <translation>Výplň</translation>
     </message>
     <message>
-        <location line="-136"/>
-        <location line="+137"/>
+        <location line="-130"/>
+        <location line="+131"/>
         <source>F</source>
         <translation>V</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::CommandButton</name>
+    <message>
+        <location filename="../src/tiled/commandbutton.cpp" line="+48"/>
+        <source>Execute Command</source>
+        <translation>Provést příkaz</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>F5</source>
+        <translation>F5</translation>
+    </message>
+    <message>
+        <location line="+39"/>
+        <location line="+61"/>
+        <source>Error Executing Command</source>
+        <translation>Chyba při provádění příkazu</translation>
+    </message>
+    <message>
+        <location line="-60"/>
+        <source>You do not have any commands setup.</source>
+        <translation>Žádné příkazy nejsou nadefinovány.</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Edit commands...</source>
+        <translation>Upravit příkazy...</translation>
+    </message>
+    <message>
+        <location line="+50"/>
+        <source>Edit Commands...</source>
+        <translation>Upravit příkazy...</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>There was an error running the command</source>
+        <translation>Při provádění příkazu nastala chyba</translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::CommandDataModel</name>
+    <message>
+        <location filename="../src/tiled/commanddatamodel.cpp" line="+74"/>
+        <source>Open in text editor</source>
+        <translation>Otevřít v textovém editoru</translation>
+    </message>
+    <message>
+        <location line="+90"/>
+        <location line="+67"/>
+        <source>&lt;new command&gt;</source>
+        <translation>&lt;nový příkaz&gt;</translation>
+    </message>
+    <message>
+        <location line="-59"/>
+        <source>Set a name for this command</source>
+        <translation>Zadat jméno tohoto příkazu</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Set the shell command to execute</source>
+        <translation>Zadat shellový příkaz k provedeni</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Show or hide this command in the command list</source>
+        <translation>Zobrazit/skrýt příkaz v seznamu</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Add a new command</source>
+        <translation>Přidat nový příkaz</translation>
+    </message>
+    <message>
+        <location line="+100"/>
+        <source>Name</source>
+        <translation>Jméno</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Command</source>
+        <translation>Příkaz</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Enable</source>
+        <translation>Povolit</translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::CommandDialog</name>
+    <message>
+        <location filename="../src/tiled/commanddialog.cpp" line="+35"/>
+        <source>Edit Commands</source>
+        <translation>Upravit příkazy</translation>
+    </message>
+</context>
+<context>
+    <name>Tiled::Internal::CreateObjectTool</name>
+    <message>
+        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
+        <location line="+111"/>
+        <source>O</source>
+        <translation>O</translation>
+    </message>
+    <message>
+        <location line="-1"/>
+        <source>Insert Objects</source>
+        <translation>Přidat objekty</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Insert Tile Objects</source>
+        <translation>Přidat dlaždicové objekty</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>T</source>
+        <translation>T</translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::Eraser</name>
     <message>
         <location filename="../src/tiled/eraser.cpp" line="+34"/>
-        <location line="+37"/>
+        <location line="+36"/>
         <source>Eraser</source>
         <translation>Guma</translation>
     </message>
     <message>
-        <location line="-34"/>
-        <location line="+35"/>
+        <location line="-33"/>
+        <location line="+34"/>
         <source>E</source>
         <translation>G</translation>
     </message>
@@ -637,7 +977,7 @@
 <context>
     <name>Tiled::Internal::LayerDock</name>
     <message>
-        <location filename="../src/tiled/layerdock.cpp" line="+165"/>
+        <location filename="../src/tiled/layerdock.cpp" line="+178"/>
         <source>Layers</source>
         <translation>Vrstvy</translation>
     </message>
@@ -650,7 +990,7 @@
 <context>
     <name>Tiled::Internal::LayerModel</name>
     <message>
-        <location filename="../src/tiled/layermodel.cpp" line="+114"/>
+        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
         <source>Layer</source>
         <translation>Vrstva</translation>
     </message>
@@ -658,51 +998,68 @@
 <context>
     <name>Tiled::Internal::MainWindow</name>
     <message>
-        <location filename="../src/tiled/mainwindow.cpp" line="+116"/>
+        <location filename="../src/tiled/mainwindow.cpp" line="+129"/>
+        <location line="+10"/>
         <source>Undo</source>
         <translation>Zpět</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="-9"/>
+        <location line="+8"/>
         <source>Redo</source>
         <translation>Znovu</translation>
     </message>
     <message>
-        <location line="+321"/>
+        <location line="+391"/>
         <source>Open Map</source>
         <translation>Otevřít mapu</translation>
     </message>
     <message>
         <location line="-13"/>
-        <location line="+78"/>
+        <location line="+79"/>
         <source>Tiled map files (*.tmx)</source>
         <translation>Dlaždicové mapy (*.tmx)</translation>
     </message>
     <message>
-        <location line="-341"/>
-        <location line="+838"/>
+        <location line="-425"/>
+        <source>Ctrl+=</source>
+        <translation>Ctrl+=</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>+</source>
+        <translation>+</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>-</source>
+        <translation>-</translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <location line="+962"/>
         <source>&amp;Layer</source>
         <translation>&amp;Vrstva</translation>
     </message>
     <message>
-        <location line="-611"/>
+        <location line="-711"/>
         <source>Error Opening Map</source>
         <translation>Chyba při otevírání mapy</translation>
     </message>
     <message>
-        <location line="+33"/>
-        <location line="+125"/>
+        <location line="+69"/>
+        <location line="+138"/>
         <source>All Files (*)</source>
         <translation>Všechny soubory (*)</translation>
     </message>
     <message>
-        <location line="-80"/>
-        <location line="+126"/>
+        <location line="-97"/>
+        <location line="+144"/>
         <source>Error Saving Map</source>
         <translation>Chyba při ukládání mapy</translation>
     </message>
     <message>
-        <location line="-95"/>
+        <location line="-108"/>
         <source>untitled.tmx</source>
         <translation>mapa.tmx</translation>
     </message>
@@ -717,12 +1074,12 @@
         <translation>V mapě jsou neuložené změny. Chcete je uložit?</translation>
     </message>
     <message>
-        <location line="+40"/>
+        <location line="+52"/>
         <source>Export As...</source>
         <translation>Exportovat jako...</translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+29"/>
         <source>Unknown File Format</source>
         <translation>Neznámý formát souboru</translation>
     </message>
@@ -732,17 +1089,21 @@
         <translation>Daný soubor má neznámou koncovku.</translation>
     </message>
     <message>
-        <location line="+43"/>
+        <location line="+47"/>
         <source>Cut</source>
         <translation>Vyjmout</translation>
     </message>
     <message>
-        <location line="+34"/>
-        <source>Add Tilesets</source>
-        <translation>Přidat sady dlaždic</translation>
+        <location line="+377"/>
+        <source>[*]%1 - Tiled</source>
+        <translation>%1[*] - Tiled</translation>
     </message>
     <message>
-        <location line="+50"/>
+        <source>Add Tilesets</source>
+        <translation type="obsolete">Přidat sady dlaždic</translation>
+    </message>
+    <message>
+        <location line="-280"/>
         <source>Add External Tileset</source>
         <translation>Přidat externí vrstvu dlaždic</translation>
     </message>
@@ -762,21 +1123,29 @@
         <translation>Mapa</translation>
     </message>
     <message>
-        <location line="+114"/>
+        <location line="+12"/>
+        <source>Automatic Mapping</source>
+        <translation>Automatická mapa</translation>
+    </message>
+    <message>
+        <location line="+123"/>
         <source>%1%</source>
         <translation>%1%</translation>
     </message>
     <message>
-        <location line="+69"/>
-        <location line="+46"/>
         <source>%1[*] - Tiled</source>
-        <translation>%1[*] - Tiled</translation>
+        <translation type="obsolete">%1[*] - Tiled</translation>
     </message>
 </context>
 <context>
     <name>Tiled::Internal::MapDocument</name>
     <message>
-        <location filename="../src/tiled/mapdocument.cpp" line="+109"/>
+        <location filename="../src/tiled/mapdocument.cpp" line="+105"/>
+        <source>untitled.tmx</source>
+        <translation>mapa.tmx</translation>
+    </message>
+    <message>
+        <location line="+39"/>
         <source>Resize Map</source>
         <translation>Změnit velikost mapy</translation>
     </message>
@@ -805,6 +1174,16 @@
         <source>Duplicate Layer</source>
         <translation>Duplikovat vrstvu</translation>
     </message>
+    <message>
+        <location line="+120"/>
+        <source>Tile</source>
+        <translation>Dlaždice</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Tileset Changes</source>
+        <translation>Změny v dlaždicích</translation>
+    </message>
 </context>
 <context>
     <name>Tiled::Internal::MapDocumentActionHandler</name>
@@ -885,7 +1264,7 @@
 <context>
     <name>Tiled::Internal::NewTilesetDialog</name>
     <message>
-        <location filename="../src/tiled/newtilesetdialog.cpp" line="+115"/>
+        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
         <location line="+7"/>
         <source>Error</source>
         <translation>Chyba</translation>
@@ -932,11 +1311,70 @@
         <translation>Změnit objekt</translation>
     </message>
 </context>
+<context>
+    <name>Tiled::Internal::ObjectSelectionTool</name>
+    <message>
+        <location filename="../src/tiled/objectselectiontool.cpp" line="+103"/>
+        <location line="+135"/>
+        <source>Select Objects</source>
+        <translation>Vybrat objekty</translation>
+    </message>
+    <message>
+        <location line="-132"/>
+        <location line="+133"/>
+        <source>S</source>
+        <translation>S</translation>
+    </message>
+    <message numerus="yes">
+        <location line="+77"/>
+        <location line="+145"/>
+        <source>Duplicate %n Object(s)</source>
+        <translation>
+            <numerusform>Duplikovat objekt</numerusform>
+            <numerusform>Duplikovat %n objekty</numerusform>
+            <numerusform>Duplikovat %n objektů</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-144"/>
+        <location line="+162"/>
+        <source>Remove %n Object(s)</source>
+        <translation>
+            <numerusform>Odstranit objekt</numerusform>
+            <numerusform>Odstranit %n objekty</numerusform>
+            <numerusform>Odstranit %n objektů</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location line="-153"/>
+        <location line="+163"/>
+        <source>Move %n Object(s) to Layer</source>
+        <translation>
+            <numerusform>Přesunout objekt do vrstvy</numerusform>
+            <numerusform>Přesunout %n objekty do vrstvy</numerusform>
+            <numerusform>Přesunout %n objektů do vrstvy</numerusform>
+        </translation>
+    </message>
+    <message>
+        <location line="-153"/>
+        <source>Object &amp;Properties...</source>
+        <translation>&amp;Vlastnosti objektu...</translation>
+    </message>
+    <message numerus="yes">
+        <location line="+107"/>
+        <source>Move %n Object(s)</source>
+        <translation>
+            <numerusform>Přesunout objekt</numerusform>
+            <numerusform>Přesunout %n objekty</numerusform>
+            <numerusform>Přesunout %n objektů</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>Tiled::Internal::PreferencesDialog</name>
     <message>
-        <location filename="../src/tiled/preferencesdialog.cpp" line="+45"/>
-        <location line="+22"/>
+        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
+        <location line="+23"/>
         <source>System default</source>
         <translation>Systémové nastavení</translation>
     </message>
@@ -944,12 +1382,12 @@
 <context>
     <name>Tiled::Internal::PropertiesDialog</name>
     <message>
-        <location filename="../src/tiled/propertiesdialog.cpp" line="+61"/>
+        <location filename="../src/tiled/propertiesdialog.cpp" line="+62"/>
         <source>%1 Properties</source>
         <translation>Vlastnosti %1</translation>
     </message>
     <message>
-        <location line="+31"/>
+        <location line="+37"/>
         <source>Layer</source>
         <translation>Vrstva</translation>
     </message>
@@ -957,13 +1395,12 @@
 <context>
     <name>Tiled::Internal::PropertiesModel</name>
     <message>
-        <location filename="../src/tiled/propertiesmodel.cpp" line="+50"/>
-        <location line="+24"/>
+        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
         <source>&lt;new property&gt;</source>
         <translation>&lt;nová vlastnost&gt;</translation>
     </message>
     <message>
-        <location line="+44"/>
+        <location line="+68"/>
         <source>Name</source>
         <translation>Jméno</translation>
     </message>
@@ -996,18 +1433,18 @@ Do you want to replace it?</source>
     <name>Tiled::Internal::SelectionTool</name>
     <message>
         <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
-        <location line="+80"/>
+        <location line="+81"/>
         <source>Rectangular Select</source>
         <translation>Obdélníkový výběr</translation>
     </message>
     <message>
-        <location line="-77"/>
-        <location line="+78"/>
+        <location line="-78"/>
+        <location line="+79"/>
         <source>R</source>
         <translation>R</translation>
     </message>
     <message>
-        <location line="-55"/>
+        <location line="-56"/>
         <source>%1, %2 - Rectangle: (%3 x %4)</source>
         <translation>%1, %2 - Obdélník: (%3 × %4)</translation>
     </message>
@@ -1015,14 +1452,14 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::StampBrush</name>
     <message>
-        <location filename="../src/tiled/stampbrush.cpp" line="+34"/>
-        <location line="+58"/>
+        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
+        <location line="+279"/>
         <source>Stamp Brush</source>
         <translation>Razítkový štětec</translation>
     </message>
     <message>
-        <location line="-55"/>
-        <location line="+56"/>
+        <location line="-276"/>
+        <location line="+277"/>
         <source>B</source>
         <translation>B</translation>
     </message>
@@ -1030,7 +1467,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::TilesetDock</name>
     <message>
-        <location filename="../src/tiled/tilesetdock.cpp" line="+236"/>
+        <location filename="../src/tiled/tilesetdock.cpp" line="+247"/>
         <source>Remove Tileset</source>
         <translation>Odstranění sady dlaždic</translation>
     </message>
@@ -1045,7 +1482,7 @@ Do you want to replace it?</source>
         <translation>Odstranit tuto sadu dlaždic a všechny její dlaždice?</translation>
     </message>
     <message>
-        <location line="+49"/>
+        <location line="+58"/>
         <source>Tilesets</source>
         <translation>Sada dlaždic</translation>
     </message>
@@ -1053,7 +1490,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::TilesetView</name>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="+207"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="+210"/>
         <source>Tile &amp;Properties...</source>
         <translation>&amp;Vlastnosti dlaždice...</translation>
     </message>
@@ -1086,7 +1523,7 @@ Do you want to replace it?</source>
 <context>
     <name>Tiled::Internal::ToolManager</name>
     <message>
-        <location filename="../src/tiled/toolmanager.cpp" line="+87"/>
+        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
         <source>Tools</source>
         <translation>Nástroje</translation>
     </message>
@@ -1130,13 +1567,12 @@ Do you want to replace it?</source>
 <context>
     <name>TmxMapReader</name>
     <message>
-        <location filename="../src/tiled/tmxmapwriter.cpp" line="+48"/>
         <source>Could not open file for writing.</source>
-        <translation>Nepodařilo se otevřít soubor pro zápis.</translation>
+        <translation type="obsolete">Nepodařilo se otevřít soubor pro zápis.</translation>
     </message>
     <message>
         <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
-        <location filename="../src/tiled/tmxmapwriter.h" line="+67"/>
+        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
         <source>Tiled map files (*.tmx)</source>
         <translation>Dlaždicové mapy (*.tmx)</translation>
     </message>
@@ -1144,103 +1580,89 @@ Do you want to replace it?</source>
 <context>
     <name>TmxReader</name>
     <message>
-        <location filename="../src/tiled/tmxmapreader.cpp" line="+139"/>
-        <location line="+21"/>
         <source>Not a map file.</source>
-        <translation>Není soubor s mapou.</translation>
+        <translation type="obsolete">Není soubor s mapou.</translation>
     </message>
     <message>
-        <location line="+21"/>
         <source>Not a tileset file.</source>
-        <translation>Není soubor se sadou dlaždic.</translation>
+        <translation type="obsolete">Není soubor se sadou dlaždic.</translation>
     </message>
     <message>
-        <location line="+15"/>
         <source>%3
 
 Line %1, column %2</source>
-        <translation>%3
+        <translation type="obsolete">%3
 
 Řádek: %1, sloupec: %2</translation>
     </message>
     <message>
-        <location line="+10"/>
         <source>File not found: %1</source>
-        <translation>Soubor nnalezen: %1</translation>
+        <translation type="obsolete">Soubor nnalezen: %1</translation>
     </message>
     <message>
-        <location line="+3"/>
         <source>Unable to read file: %1</source>
-        <translation>Nepodařilo se přečíst soubor: %1</translation>
+        <translation type="obsolete">Nepodařilo se přečíst soubor: %1</translation>
     </message>
     <message>
-        <location line="+61"/>
         <source>Unsupported map orientation: &quot;%1&quot;</source>
-        <translation>Nepodporovaná orientace mapy: &quot;%1&quot;</translation>
+        <translation type="obsolete">Nepodporovaná orientace mapy: &quot;%1&quot;</translation>
     </message>
     <message>
-        <location line="+56"/>
         <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
-        <translation>Špatné parametry sady dlaždic &apos;%1&apos;</translation>
+        <translation type="obsolete">Špatné parametry sady dlaždic &apos;%1&apos;</translation>
     </message>
     <message>
-        <location line="+54"/>
         <source>Error while loading tileset &apos;%1&apos;: %2</source>
-        <translation>Chyba při načítání sady dlaždic &apos;%1&apos;: %2</translation>
+        <translation type="obsolete">Chyba při načítání sady dlaždic &apos;%1&apos;: %2</translation>
     </message>
     <message>
-        <location line="+22"/>
         <source>Invalid tile ID: %1</source>
-        <translation>Neplatné ID dlaždice: %1</translation>
+        <translation type="obsolete">Neplatné ID dlaždice: %1</translation>
     </message>
     <message>
-        <location line="+33"/>
         <source>Error loading tileset image:
 &apos;%1&apos;</source>
-        <translation>Chyba načítání obrázku sady dlaždic: &apos;%1&apos;</translation>
+        <translation type="obsolete">Chyba načítání obrázku sady dlaždic: &apos;%1&apos;</translation>
     </message>
     <message>
-        <location line="+49"/>
         <source>Too many &lt;tile&gt; elements</source>
-        <translation>Příliš mnoho &lt;title&gt; elementů</translation>
+        <translation type="obsolete">Příliš mnoho &lt;title&gt; elementů</translation>
     </message>
     <message>
-        <location line="+11"/>
-        <location line="+66"/>
-        <location line="+39"/>
         <source>Invalid tile: %1</source>
-        <translation>Neplatné jméno: %1</translation>
+        <translation type="obsolete">Neplatné jméno: %1</translation>
     </message>
     <message>
-        <location line="-85"/>
         <source>Unknown encoding: %1</source>
-        <translation>Neplatné kódování: %1</translation>
+        <translation type="obsolete">Neplatné kódování: %1</translation>
     </message>
     <message>
-        <location line="+19"/>
         <source>Compression method &apos;%1&apos; not supported</source>
-        <translation>Kompresní metoda &apos;%1&apos; není podporována</translation>
+        <translation type="obsolete">Kompresní metoda &apos;%1&apos; není podporována</translation>
     </message>
     <message>
-        <location line="+6"/>
-        <location line="+39"/>
         <source>Corrupt layer data for layer &apos;%1&apos;</source>
-        <translation>Špatná data vrstvy &apos;%1&apos;</translation>
+        <translation type="obsolete">Špatná data vrstvy &apos;%1&apos;</translation>
     </message>
     <message>
-        <location line="+12"/>
         <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
-        <translation>Nepodařilo se přečíst jméno na (%1, %2) ve vrstvě &apos;%3&apos;</translation>
+        <translation type="obsolete">Nepodařilo se přečíst jméno na (%1, %2) ve vrstvě &apos;%3&apos;</translation>
     </message>
     <message>
-        <location line="+20"/>
         <source>Invalid global tile id (less than 0): %1</source>
-        <translation>Neplatné globální ID dlaždice (menší než 0): %1</translation>
+        <translation type="obsolete">Neplatné globální ID dlaždice (menší než 0): %1</translation>
     </message>
     <message>
-        <location line="+6"/>
         <source>Tile used but no tilesets specified</source>
-        <translation>Použití dlaždice bez sady dlaždic</translation>
+        <translation type="obsolete">Použití dlaždice bez sady dlaždic</translation>
+    </message>
+</context>
+<context>
+    <name>TmxViewer</name>
+    <message>
+        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+166"/>
+        <source>TMX Viewer</source>
+        <translation>Prohlížeč souborů TMX</translation>
     </message>
 </context>
 <context>
@@ -1277,7 +1699,7 @@ Line %1, column %2</source>
         <translation>Změna vlastností vrstvy objeků</translation>
     </message>
     <message>
-        <location filename="../src/tiled/changeproperties.cpp" line="+33"/>
+        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
         <source>Change %1 Properties</source>
         <translation>Změna vlastností: %1</translation>
     </message>
@@ -1357,7 +1779,7 @@ Line %1, column %2</source>
         <translation>Posunutí sady dlaždic</translation>
     </message>
     <message>
-        <location filename="../src/tiled/tilesetview.cpp" line="-147"/>
+        <location filename="../src/tiled/tilesetview.cpp" line="-151"/>
         <source>Import Tileset</source>
         <translation>Import sady dlaždic</translation>
     </message>
@@ -1366,11 +1788,16 @@ Line %1, column %2</source>
         <source>Export Tileset</source>
         <translation>Export sady dlaždic</translation>
     </message>
+    <message>
+        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
+        <source>Move Object to Layer</source>
+        <translation>Přesunutí objektu do vrstvy</translation>
+    </message>
 </context>
 <context>
     <name>Utils</name>
     <message>
-        <location filename="../src/tiled/utils.cpp" line="+32"/>
+        <location filename="../src/tiled/utils.cpp" line="+31"/>
         <source>Image files</source>
         <translation>Soubory s obrázky</translation>
     </message>
